API of the PyOTI package
========================

Subpackages
-----------

.. toctree::

    pyoti.calibration
    pyoti.data
    pyoti.evaluate
    pyoti.modification
    pyoti.region

Submodules
----------

pyoti.config module
-------------------

.. automodule:: pyoti.config
    :members:
    :undoc-members:
    :show-inheritance:

pyoti.experiment module
-----------------------

.. automodule:: pyoti.experiment
    :members:
    :undoc-members:
    :show-inheritance:

pyoti.graph module
------------------

.. automodule:: pyoti.graph
    :members:
    :undoc-members:
    :show-inheritance:

pyoti.gui module
----------------

.. automodule:: pyoti.gui
    :members:
    :undoc-members:
    :show-inheritance:

pyoti.helpers module
--------------------

.. automodule:: pyoti.helpers
    :members:
    :undoc-members:
    :show-inheritance:

pyoti.picklable module
----------------------

.. automodule:: pyoti.picklable
    :members:
    :undoc-members:
    :show-inheritance:

pyoti.traces module
-------------------

.. automodule:: pyoti.traces
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyoti
    :members:
    :undoc-members:
    :show-inheritance:
